from fastapi import APIRouter, Depends, status
from sqlalchemy.orm import Session
from core.database import get_db
from schemas.contact import ContactCreate, ContactSchema
from helpers.contact_helpers import create_contact, sanitize_contact_data, format_contact_response

router = APIRouter()

@router.post("/contact", status_code=status.HTTP_201_CREATED, response_model=ContactSchema)
async def create_contact_submission(
    contact_data: ContactCreate,
    db: Session = Depends(get_db)
):
    """Create a new contact submission with email validation"""
    # Sanitize input data
    sanitized_data = sanitize_contact_data(contact_data)
    
    # Create contact using helper function
    contact = create_contact(db=db, contact_data=sanitized_data)
    
    # Format response
    return format_contact_response(contact)